.. default-domain:: py
.. currentmodule:: fastnumbers

.. _timing:

Timing
======

.. contents::
    :local:

Just how much faster is ``fastnumbers`` than a pure python implementation?
This data has moved to
https://github.com/SethMMorton/fastnumbers/tree/main/profiling.
